api

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 26, 2026 License: AGPL-3.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

const (
	Streaming_Search_FullMethodName                  = "/streaming.Streaming/Search"
	Streaming_GetArtist_FullMethodName               = "/streaming.Streaming/GetArtist"
	Streaming_GetArtistFull_FullMethodName           = "/streaming.Streaming/GetArtistFull"
	Streaming_GetAlbumFull_FullMethodName            = "/streaming.Streaming/GetAlbumFull"
	Streaming_GetPlaylist_FullMethodName             = "/streaming.Streaming/GetPlaylist"
	Streaming_GetPlaylistFull_FullMethodName         = "/streaming.Streaming/GetPlaylistFull"
	Streaming_GetTrack_FullMethodName                = "/streaming.Streaming/GetTrack"
	Streaming_GetPageEntry_FullMethodName            = "/streaming.Streaming/GetPageEntry"
	Streaming_GetPage_FullMethodName                 = "/streaming.Streaming/GetPage"
	Streaming_GetStreamingInfo_FullMethodName        = "/streaming.Streaming/GetStreamingInfo"
	Streaming_ListArtistPopularTracks_FullMethodName = "/streaming.Streaming/ListArtistPopularTracks"
	Streaming_ListUserArtists_FullMethodName         = "/streaming.Streaming/ListUserArtists"
	Streaming_ListUserAlbums_FullMethodName          = "/streaming.Streaming/ListUserAlbums"
	Streaming_ListUserPlaylists_FullMethodName       = "/streaming.Streaming/ListUserPlaylists"
)

Variables

var ErrNotFound = errors.New("entry not found")
var File_proto_streaming_proto protoreflect.FileDescriptor
var Streaming_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "streaming.Streaming",
	HandlerType: (*StreamingServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Search",
			Handler:    _Streaming_Search_Handler,
		},
		{
			MethodName: "GetArtist",
			Handler:    _Streaming_GetArtist_Handler,
		},
		{
			MethodName: "GetArtistFull",
			Handler:    _Streaming_GetArtistFull_Handler,
		},
		{
			MethodName: "GetAlbumFull",
			Handler:    _Streaming_GetAlbumFull_Handler,
		},
		{
			MethodName: "GetPlaylist",
			Handler:    _Streaming_GetPlaylist_Handler,
		},
		{
			MethodName: "GetPlaylistFull",
			Handler:    _Streaming_GetPlaylistFull_Handler,
		},
		{
			MethodName: "GetTrack",
			Handler:    _Streaming_GetTrack_Handler,
		},
		{
			MethodName: "GetPageEntry",
			Handler:    _Streaming_GetPageEntry_Handler,
		},
		{
			MethodName: "GetPage",
			Handler:    _Streaming_GetPage_Handler,
		},
		{
			MethodName: "GetStreamingInfo",
			Handler:    _Streaming_GetStreamingInfo_Handler,
		},
		{
			MethodName: "ListArtistPopularTracks",
			Handler:    _Streaming_ListArtistPopularTracks_Handler,
		},
		{
			MethodName: "ListUserArtists",
			Handler:    _Streaming_ListUserArtists_Handler,
		},
		{
			MethodName: "ListUserAlbums",
			Handler:    _Streaming_ListUserAlbums_Handler,
		},
		{
			MethodName: "ListUserPlaylists",
			Handler:    _Streaming_ListUserPlaylists_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/streaming.proto",
}

Streaming_ServiceDesc is the grpc.ServiceDesc for Streaming service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterStreamingServer

func RegisterStreamingServer(s grpc.ServiceRegistrar, srv StreamingServer)

func RequestID

func RequestID(ctx context.Context) (uuid.UUID, error)

Types

type API

type API struct {
	UnimplementedStreamingServer
	// contains filtered or unexported fields
}

func Init

func Init(logger *slog.Logger, port int, minMatch float32, tidal *tidal.Tidal) (*API, error)

func (*API) GetAlbumFull

func (a *API) GetAlbumFull(ctx context.Context, id *Id) (*AlbumFull, error)

func (*API) GetArtist

func (a *API) GetArtist(ctx context.Context, id *Id) (*Artist, error)

func (*API) GetArtistFull

func (a *API) GetArtistFull(ctx context.Context, id *Id) (*ArtistFull, error)

func (*API) GetPage

func (a *API) GetPage(ctx context.Context, empty *emptypb.Empty) (*Page, error)

func (*API) GetPageEntry

func (a *API) GetPageEntry(ctx context.Context, req *Id) (*PageEntry, error)

func (*API) GetPlaylist

func (a *API) GetPlaylist(ctx context.Context, id *Id) (*Playlist, error)

func (*API) GetPlaylistFull

func (a *API) GetPlaylistFull(ctx context.Context, id *Id) (*PlaylistFull, error)

func (*API) GetStreamingInfo

func (a *API) GetStreamingInfo(ctx context.Context, id *Id) (*StreamingInfo, error)

func (*API) GetTrack

func (a *API) GetTrack(ctx context.Context, id *Id) (*Track, error)

func (*API) ListArtistPopularTracks

func (a *API) ListArtistPopularTracks(ctx context.Context, id *Id) (*Tracks, error)

func (*API) ListUserAlbums

func (a *API) ListUserAlbums(ctx context.Context, empty *emptypb.Empty) (*Albums, error)

func (*API) ListUserArtists

func (a *API) ListUserArtists(ctx context.Context, empty *emptypb.Empty) (*Artists, error)

func (*API) ListUserPlaylists

func (a *API) ListUserPlaylists(ctx context.Context, empty *emptypb.Empty) (*Playlists, error)

func (*API) Run

func (a *API) Run() error

func (*API) Search

func (a *API) Search(ctx context.Context, req *SearchQuery) (*SearchRes, error)

type Album

type Album struct {
	Id       string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Title    string                 `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	Version  string                 `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	Release  *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=release,proto3,oneof" json:"release,omitempty"`
	ImageUrl *string                `protobuf:"bytes,5,opt,name=image_url,json=imageUrl,proto3,oneof" json:"image_url,omitempty"`
	Artists  []*Artist              `protobuf:"bytes,6,rep,name=artists,proto3" json:"artists,omitempty"`
	// contains filtered or unexported fields
}

func (*Album) Descriptor deprecated

func (*Album) Descriptor() ([]byte, []int)

Deprecated: Use Album.ProtoReflect.Descriptor instead.

func (*Album) GetArtists

func (x *Album) GetArtists() []*Artist

func (*Album) GetId

func (x *Album) GetId() string

func (*Album) GetImageUrl

func (x *Album) GetImageUrl() string

func (*Album) GetRelease

func (x *Album) GetRelease() *timestamppb.Timestamp

func (*Album) GetTitle

func (x *Album) GetTitle() string

func (*Album) GetVersion

func (x *Album) GetVersion() string

func (*Album) ProtoMessage

func (*Album) ProtoMessage()

func (*Album) ProtoReflect

func (x *Album) ProtoReflect() protoreflect.Message

func (*Album) Reset

func (x *Album) Reset()

func (*Album) String

func (x *Album) String() string

type AlbumFull

type AlbumFull struct {
	Album  *Album   `protobuf:"bytes,1,opt,name=album,proto3" json:"album,omitempty"`
	Tracks []*Track `protobuf:"bytes,2,rep,name=tracks,proto3" json:"tracks,omitempty"`
	// contains filtered or unexported fields
}

func (*AlbumFull) Descriptor deprecated

func (*AlbumFull) Descriptor() ([]byte, []int)

Deprecated: Use AlbumFull.ProtoReflect.Descriptor instead.

func (*AlbumFull) GetAlbum

func (x *AlbumFull) GetAlbum() *Album

func (*AlbumFull) GetTracks

func (x *AlbumFull) GetTracks() []*Track

func (*AlbumFull) ProtoMessage

func (*AlbumFull) ProtoMessage()

func (*AlbumFull) ProtoReflect

func (x *AlbumFull) ProtoReflect() protoreflect.Message

func (*AlbumFull) Reset

func (x *AlbumFull) Reset()

func (*AlbumFull) String

func (x *AlbumFull) String() string

type Albums

type Albums struct {
	List []*Album `protobuf:"bytes,1,rep,name=list,proto3" json:"list,omitempty"`
	// contains filtered or unexported fields
}

func (*Albums) Descriptor deprecated

func (*Albums) Descriptor() ([]byte, []int)

Deprecated: Use Albums.ProtoReflect.Descriptor instead.

func (*Albums) GetList

func (x *Albums) GetList() []*Album

func (*Albums) ProtoMessage

func (*Albums) ProtoMessage()

func (*Albums) ProtoReflect

func (x *Albums) ProtoReflect() protoreflect.Message

func (*Albums) Reset

func (x *Albums) Reset()

func (*Albums) String

func (x *Albums) String() string

type Artist

type Artist struct {
	Id       string  `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Title    string  `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	ImageUrl *string `protobuf:"bytes,3,opt,name=image_url,json=imageUrl,proto3,oneof" json:"image_url,omitempty"`
	// contains filtered or unexported fields
}

func (*Artist) Descriptor deprecated

func (*Artist) Descriptor() ([]byte, []int)

Deprecated: Use Artist.ProtoReflect.Descriptor instead.

func (*Artist) GetId

func (x *Artist) GetId() string

func (*Artist) GetImageUrl

func (x *Artist) GetImageUrl() string

func (*Artist) GetTitle

func (x *Artist) GetTitle() string

func (*Artist) ProtoMessage

func (*Artist) ProtoMessage()

func (*Artist) ProtoReflect

func (x *Artist) ProtoReflect() protoreflect.Message

func (*Artist) Reset

func (x *Artist) Reset()

func (*Artist) String

func (x *Artist) String() string

type ArtistFull

type ArtistFull struct {
	Artist        *Artist   `protobuf:"bytes,1,opt,name=artist,proto3" json:"artist,omitempty"`
	PopularTracks []*Track  `protobuf:"bytes,2,rep,name=popular_tracks,json=popularTracks,proto3" json:"popular_tracks,omitempty"`
	Albums        []*Album  `protobuf:"bytes,3,rep,name=albums,proto3" json:"albums,omitempty"`
	SinglesAndEps []*Album  `protobuf:"bytes,4,rep,name=singles_and_eps,json=singlesAndEps,proto3" json:"singles_and_eps,omitempty"`
	Appearances   []*Album  `protobuf:"bytes,5,rep,name=appearances,proto3" json:"appearances,omitempty"`
	Similar       []*Artist `protobuf:"bytes,6,rep,name=similar,proto3" json:"similar,omitempty"`
	// contains filtered or unexported fields
}

func (*ArtistFull) Descriptor deprecated

func (*ArtistFull) Descriptor() ([]byte, []int)

Deprecated: Use ArtistFull.ProtoReflect.Descriptor instead.

func (*ArtistFull) GetAlbums

func (x *ArtistFull) GetAlbums() []*Album

func (*ArtistFull) GetAppearances

func (x *ArtistFull) GetAppearances() []*Album

func (*ArtistFull) GetArtist

func (x *ArtistFull) GetArtist() *Artist

func (*ArtistFull) GetPopularTracks

func (x *ArtistFull) GetPopularTracks() []*Track

func (*ArtistFull) GetSimilar added in v0.1.3

func (x *ArtistFull) GetSimilar() []*Artist

func (*ArtistFull) GetSinglesAndEps

func (x *ArtistFull) GetSinglesAndEps() []*Album

func (*ArtistFull) ProtoMessage

func (*ArtistFull) ProtoMessage()

func (*ArtistFull) ProtoReflect

func (x *ArtistFull) ProtoReflect() protoreflect.Message

func (*ArtistFull) Reset

func (x *ArtistFull) Reset()

func (*ArtistFull) String

func (x *ArtistFull) String() string

type Artists

type Artists struct {
	List []*Artist `protobuf:"bytes,1,rep,name=list,proto3" json:"list,omitempty"`
	// contains filtered or unexported fields
}

func (*Artists) Descriptor deprecated

func (*Artists) Descriptor() ([]byte, []int)

Deprecated: Use Artists.ProtoReflect.Descriptor instead.

func (*Artists) GetList

func (x *Artists) GetList() []*Artist

func (*Artists) ProtoMessage

func (*Artists) ProtoMessage()

func (*Artists) ProtoReflect

func (x *Artists) ProtoReflect() protoreflect.Message

func (*Artists) Reset

func (x *Artists) Reset()

func (*Artists) String

func (x *Artists) String() string

type FoundAlbum added in v0.1.3

type FoundAlbum struct {
	Rating float32 `protobuf:"fixed32,1,opt,name=rating,proto3" json:"rating,omitempty"`
	Album  *Album  `protobuf:"bytes,2,opt,name=album,proto3" json:"album,omitempty"`
	// contains filtered or unexported fields
}

func (*FoundAlbum) Descriptor deprecated added in v0.1.3

func (*FoundAlbum) Descriptor() ([]byte, []int)

Deprecated: Use FoundAlbum.ProtoReflect.Descriptor instead.

func (*FoundAlbum) GetAlbum added in v0.1.3

func (x *FoundAlbum) GetAlbum() *Album

func (*FoundAlbum) GetRating added in v0.1.3

func (x *FoundAlbum) GetRating() float32

func (*FoundAlbum) ProtoMessage added in v0.1.3

func (*FoundAlbum) ProtoMessage()

func (*FoundAlbum) ProtoReflect added in v0.1.3

func (x *FoundAlbum) ProtoReflect() protoreflect.Message

func (*FoundAlbum) Reset added in v0.1.3

func (x *FoundAlbum) Reset()

func (*FoundAlbum) String added in v0.1.3

func (x *FoundAlbum) String() string

type FoundArtist added in v0.1.3

type FoundArtist struct {
	Rating float32 `protobuf:"fixed32,1,opt,name=rating,proto3" json:"rating,omitempty"`
	Artist *Artist `protobuf:"bytes,2,opt,name=artist,proto3" json:"artist,omitempty"`
	// contains filtered or unexported fields
}

func (*FoundArtist) Descriptor deprecated added in v0.1.3

func (*FoundArtist) Descriptor() ([]byte, []int)

Deprecated: Use FoundArtist.ProtoReflect.Descriptor instead.

func (*FoundArtist) GetArtist added in v0.1.3

func (x *FoundArtist) GetArtist() *Artist

func (*FoundArtist) GetRating added in v0.1.3

func (x *FoundArtist) GetRating() float32

func (*FoundArtist) ProtoMessage added in v0.1.3

func (*FoundArtist) ProtoMessage()

func (*FoundArtist) ProtoReflect added in v0.1.3

func (x *FoundArtist) ProtoReflect() protoreflect.Message

func (*FoundArtist) Reset added in v0.1.3

func (x *FoundArtist) Reset()

func (*FoundArtist) String added in v0.1.3

func (x *FoundArtist) String() string

type FoundPlaylist added in v0.1.3

type FoundPlaylist struct {
	Rating   float32   `protobuf:"fixed32,1,opt,name=rating,proto3" json:"rating,omitempty"`
	Playlist *Playlist `protobuf:"bytes,2,opt,name=playlist,proto3" json:"playlist,omitempty"`
	// contains filtered or unexported fields
}

func (*FoundPlaylist) Descriptor deprecated added in v0.1.3

func (*FoundPlaylist) Descriptor() ([]byte, []int)

Deprecated: Use FoundPlaylist.ProtoReflect.Descriptor instead.

func (*FoundPlaylist) GetPlaylist added in v0.1.3

func (x *FoundPlaylist) GetPlaylist() *Playlist

func (*FoundPlaylist) GetRating added in v0.1.3

func (x *FoundPlaylist) GetRating() float32

func (*FoundPlaylist) ProtoMessage added in v0.1.3

func (*FoundPlaylist) ProtoMessage()

func (*FoundPlaylist) ProtoReflect added in v0.1.3

func (x *FoundPlaylist) ProtoReflect() protoreflect.Message

func (*FoundPlaylist) Reset added in v0.1.3

func (x *FoundPlaylist) Reset()

func (*FoundPlaylist) String added in v0.1.3

func (x *FoundPlaylist) String() string

type FoundTrack added in v0.1.3

type FoundTrack struct {
	Rating float32 `protobuf:"fixed32,1,opt,name=rating,proto3" json:"rating,omitempty"`
	Track  *Track  `protobuf:"bytes,2,opt,name=track,proto3" json:"track,omitempty"`
	// contains filtered or unexported fields
}

func (*FoundTrack) Descriptor deprecated added in v0.1.3

func (*FoundTrack) Descriptor() ([]byte, []int)

Deprecated: Use FoundTrack.ProtoReflect.Descriptor instead.

func (*FoundTrack) GetRating added in v0.1.3

func (x *FoundTrack) GetRating() float32

func (*FoundTrack) GetTrack added in v0.1.3

func (x *FoundTrack) GetTrack() *Track

func (*FoundTrack) ProtoMessage added in v0.1.3

func (*FoundTrack) ProtoMessage()

func (*FoundTrack) ProtoReflect added in v0.1.3

func (x *FoundTrack) ProtoReflect() protoreflect.Message

func (*FoundTrack) Reset added in v0.1.3

func (x *FoundTrack) Reset()

func (*FoundTrack) String added in v0.1.3

func (x *FoundTrack) String() string

type Id

type Id struct {
	Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*Id) Descriptor deprecated

func (*Id) Descriptor() ([]byte, []int)

Deprecated: Use Id.ProtoReflect.Descriptor instead.

func (*Id) GetValue

func (x *Id) GetValue() string

func (*Id) ProtoMessage

func (*Id) ProtoMessage()

func (*Id) ProtoReflect

func (x *Id) ProtoReflect() protoreflect.Message

func (*Id) Reset

func (x *Id) Reset()

func (*Id) String

func (x *Id) String() string

type MixedPageEntryItem

type MixedPageEntryItem struct {

	// Types that are valid to be assigned to Content:
	//
	//	*MixedPageEntryItem_Album
	//	*MixedPageEntryItem_Playlist
	//	*MixedPageEntryItem_Artist
	Content isMixedPageEntryItem_Content `protobuf_oneof:"content"`
	// contains filtered or unexported fields
}

func (*MixedPageEntryItem) Descriptor deprecated

func (*MixedPageEntryItem) Descriptor() ([]byte, []int)

Deprecated: Use MixedPageEntryItem.ProtoReflect.Descriptor instead.

func (*MixedPageEntryItem) GetAlbum

func (x *MixedPageEntryItem) GetAlbum() *Album

func (*MixedPageEntryItem) GetArtist

func (x *MixedPageEntryItem) GetArtist() *Artist

func (*MixedPageEntryItem) GetContent

func (x *MixedPageEntryItem) GetContent() isMixedPageEntryItem_Content

func (*MixedPageEntryItem) GetPlaylist

func (x *MixedPageEntryItem) GetPlaylist() *Playlist

func (*MixedPageEntryItem) ProtoMessage

func (*MixedPageEntryItem) ProtoMessage()

func (*MixedPageEntryItem) ProtoReflect

func (x *MixedPageEntryItem) ProtoReflect() protoreflect.Message

func (*MixedPageEntryItem) Reset

func (x *MixedPageEntryItem) Reset()

func (*MixedPageEntryItem) String

func (x *MixedPageEntryItem) String() string

type MixedPageEntryItem_Album

type MixedPageEntryItem_Album struct {
	Album *Album `protobuf:"bytes,1,opt,name=album,proto3,oneof"`
}

type MixedPageEntryItem_Artist

type MixedPageEntryItem_Artist struct {
	Artist *Artist `protobuf:"bytes,3,opt,name=artist,proto3,oneof"`
}

type MixedPageEntryItem_Playlist

type MixedPageEntryItem_Playlist struct {
	Playlist *Playlist `protobuf:"bytes,2,opt,name=playlist,proto3,oneof"`
}

type MixedPageEntryItems

type MixedPageEntryItems struct {
	Items []*MixedPageEntryItem `protobuf:"bytes,1,rep,name=items,proto3" json:"items,omitempty"`
	// contains filtered or unexported fields
}

func (*MixedPageEntryItems) Descriptor deprecated

func (*MixedPageEntryItems) Descriptor() ([]byte, []int)

Deprecated: Use MixedPageEntryItems.ProtoReflect.Descriptor instead.

func (*MixedPageEntryItems) GetItems

func (x *MixedPageEntryItems) GetItems() []*MixedPageEntryItem

func (*MixedPageEntryItems) ProtoMessage

func (*MixedPageEntryItems) ProtoMessage()

func (*MixedPageEntryItems) ProtoReflect

func (x *MixedPageEntryItems) ProtoReflect() protoreflect.Message

func (*MixedPageEntryItems) Reset

func (x *MixedPageEntryItems) Reset()

func (*MixedPageEntryItems) String

func (x *MixedPageEntryItems) String() string

type Page

type Page struct {
	Entries []*PageEntry `protobuf:"bytes,1,rep,name=entries,proto3" json:"entries,omitempty"`
	// contains filtered or unexported fields
}

func (*Page) Descriptor deprecated

func (*Page) Descriptor() ([]byte, []int)

Deprecated: Use Page.ProtoReflect.Descriptor instead.

func (*Page) GetEntries

func (x *Page) GetEntries() []*PageEntry

func (*Page) ProtoMessage

func (*Page) ProtoMessage()

func (*Page) ProtoReflect

func (x *Page) ProtoReflect() protoreflect.Message

func (*Page) Reset

func (x *Page) Reset()

func (*Page) String

func (x *Page) String() string

type PageEntry

type PageEntry struct {
	Id    string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	// Types that are valid to be assigned to Content:
	//
	//	*PageEntry_MixedItems
	//	*PageEntry_Tracks
	Content isPageEntry_Content `protobuf_oneof:"content"`
	// contains filtered or unexported fields
}

func (*PageEntry) Descriptor deprecated

func (*PageEntry) Descriptor() ([]byte, []int)

Deprecated: Use PageEntry.ProtoReflect.Descriptor instead.

func (*PageEntry) GetContent

func (x *PageEntry) GetContent() isPageEntry_Content

func (*PageEntry) GetId added in v0.1.3

func (x *PageEntry) GetId() string

func (*PageEntry) GetMixedItems

func (x *PageEntry) GetMixedItems() *MixedPageEntryItems

func (*PageEntry) GetTitle

func (x *PageEntry) GetTitle() string

func (*PageEntry) GetTracks

func (x *PageEntry) GetTracks() *Tracks

func (*PageEntry) ProtoMessage

func (*PageEntry) ProtoMessage()

func (*PageEntry) ProtoReflect

func (x *PageEntry) ProtoReflect() protoreflect.Message

func (*PageEntry) Reset

func (x *PageEntry) Reset()

func (*PageEntry) String

func (x *PageEntry) String() string

type PageEntry_MixedItems

type PageEntry_MixedItems struct {
	MixedItems *MixedPageEntryItems `protobuf:"bytes,3,opt,name=mixedItems,proto3,oneof"`
}

type PageEntry_Tracks

type PageEntry_Tracks struct {
	Tracks *Tracks `protobuf:"bytes,4,opt,name=tracks,proto3,oneof"`
}

type Playlist

type Playlist struct {
	Id          string  `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Title       string  `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	ImageUrl    *string `protobuf:"bytes,3,opt,name=image_url,json=imageUrl,proto3,oneof" json:"image_url,omitempty"`
	Description *string `protobuf:"bytes,4,opt,name=description,proto3,oneof" json:"description,omitempty"`
	// contains filtered or unexported fields
}

func (*Playlist) Descriptor deprecated

func (*Playlist) Descriptor() ([]byte, []int)

Deprecated: Use Playlist.ProtoReflect.Descriptor instead.

func (*Playlist) GetDescription

func (x *Playlist) GetDescription() string

func (*Playlist) GetId

func (x *Playlist) GetId() string

func (*Playlist) GetImageUrl

func (x *Playlist) GetImageUrl() string

func (*Playlist) GetTitle

func (x *Playlist) GetTitle() string

func (*Playlist) ProtoMessage

func (*Playlist) ProtoMessage()

func (*Playlist) ProtoReflect

func (x *Playlist) ProtoReflect() protoreflect.Message

func (*Playlist) Reset

func (x *Playlist) Reset()

func (*Playlist) String

func (x *Playlist) String() string

type PlaylistFull

type PlaylistFull struct {
	Playlist *Playlist `protobuf:"bytes,1,opt,name=playlist,proto3" json:"playlist,omitempty"`
	Tracks   []*Track  `protobuf:"bytes,2,rep,name=tracks,proto3" json:"tracks,omitempty"`
	// contains filtered or unexported fields
}

func (*PlaylistFull) Descriptor deprecated

func (*PlaylistFull) Descriptor() ([]byte, []int)

Deprecated: Use PlaylistFull.ProtoReflect.Descriptor instead.

func (*PlaylistFull) GetPlaylist

func (x *PlaylistFull) GetPlaylist() *Playlist

func (*PlaylistFull) GetTracks

func (x *PlaylistFull) GetTracks() []*Track

func (*PlaylistFull) ProtoMessage

func (*PlaylistFull) ProtoMessage()

func (*PlaylistFull) ProtoReflect

func (x *PlaylistFull) ProtoReflect() protoreflect.Message

func (*PlaylistFull) Reset

func (x *PlaylistFull) Reset()

func (*PlaylistFull) String

func (x *PlaylistFull) String() string

type Playlists

type Playlists struct {
	List []*Playlist `protobuf:"bytes,1,rep,name=list,proto3" json:"list,omitempty"`
	// contains filtered or unexported fields
}

func (*Playlists) Descriptor deprecated

func (*Playlists) Descriptor() ([]byte, []int)

Deprecated: Use Playlists.ProtoReflect.Descriptor instead.

func (*Playlists) GetList

func (x *Playlists) GetList() []*Playlist

func (*Playlists) ProtoMessage

func (*Playlists) ProtoMessage()

func (*Playlists) ProtoReflect

func (x *Playlists) ProtoReflect() protoreflect.Message

func (*Playlists) Reset

func (x *Playlists) Reset()

func (*Playlists) String

func (x *Playlists) String() string

type SearchQuery

type SearchQuery struct {
	Query string `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchQuery) Descriptor deprecated

func (*SearchQuery) Descriptor() ([]byte, []int)

Deprecated: Use SearchQuery.ProtoReflect.Descriptor instead.

func (*SearchQuery) GetQuery

func (x *SearchQuery) GetQuery() string

func (*SearchQuery) ProtoMessage

func (*SearchQuery) ProtoMessage()

func (*SearchQuery) ProtoReflect

func (x *SearchQuery) ProtoReflect() protoreflect.Message

func (*SearchQuery) Reset

func (x *SearchQuery) Reset()

func (*SearchQuery) String

func (x *SearchQuery) String() string

type SearchRes

type SearchRes struct {
	Artists   []*FoundArtist   `protobuf:"bytes,1,rep,name=artists,proto3" json:"artists,omitempty"`
	Albums    []*FoundAlbum    `protobuf:"bytes,2,rep,name=albums,proto3" json:"albums,omitempty"`
	Tracks    []*FoundTrack    `protobuf:"bytes,3,rep,name=tracks,proto3" json:"tracks,omitempty"`
	Playlists []*FoundPlaylist `protobuf:"bytes,4,rep,name=playlists,proto3" json:"playlists,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchRes) Descriptor deprecated

func (*SearchRes) Descriptor() ([]byte, []int)

Deprecated: Use SearchRes.ProtoReflect.Descriptor instead.

func (*SearchRes) GetAlbums

func (x *SearchRes) GetAlbums() []*FoundAlbum

func (*SearchRes) GetArtists

func (x *SearchRes) GetArtists() []*FoundArtist

func (*SearchRes) GetPlaylists added in v0.1.3

func (x *SearchRes) GetPlaylists() []*FoundPlaylist

func (*SearchRes) GetTracks

func (x *SearchRes) GetTracks() []*FoundTrack

func (*SearchRes) ProtoMessage

func (*SearchRes) ProtoMessage()

func (*SearchRes) ProtoReflect

func (x *SearchRes) ProtoReflect() protoreflect.Message

func (*SearchRes) Reset

func (x *SearchRes) Reset()

func (*SearchRes) String

func (x *SearchRes) String() string

type StreamingClient

type StreamingClient interface {
	Search(ctx context.Context, in *SearchQuery, opts ...grpc.CallOption) (*SearchRes, error)
	GetArtist(ctx context.Context, in *Id, opts ...grpc.CallOption) (*Artist, error)
	GetArtistFull(ctx context.Context, in *Id, opts ...grpc.CallOption) (*ArtistFull, error)
	GetAlbumFull(ctx context.Context, in *Id, opts ...grpc.CallOption) (*AlbumFull, error)
	GetPlaylist(ctx context.Context, in *Id, opts ...grpc.CallOption) (*Playlist, error)
	GetPlaylistFull(ctx context.Context, in *Id, opts ...grpc.CallOption) (*PlaylistFull, error)
	GetTrack(ctx context.Context, in *Id, opts ...grpc.CallOption) (*Track, error)
	GetPageEntry(ctx context.Context, in *Id, opts ...grpc.CallOption) (*PageEntry, error)
	GetPage(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*Page, error)
	GetStreamingInfo(ctx context.Context, in *Id, opts ...grpc.CallOption) (*StreamingInfo, error)
	ListArtistPopularTracks(ctx context.Context, in *Id, opts ...grpc.CallOption) (*Tracks, error)
	ListUserArtists(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*Artists, error)
	ListUserAlbums(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*Albums, error)
	ListUserPlaylists(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*Playlists, error)
}

StreamingClient is the client API for Streaming service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewStreamingClient

func NewStreamingClient(cc grpc.ClientConnInterface) StreamingClient

type StreamingInfo

type StreamingInfo struct {
	Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
	// contains filtered or unexported fields
}

func (*StreamingInfo) Descriptor deprecated

func (*StreamingInfo) Descriptor() ([]byte, []int)

Deprecated: Use StreamingInfo.ProtoReflect.Descriptor instead.

func (*StreamingInfo) GetUrl

func (x *StreamingInfo) GetUrl() string

func (*StreamingInfo) ProtoMessage

func (*StreamingInfo) ProtoMessage()

func (*StreamingInfo) ProtoReflect

func (x *StreamingInfo) ProtoReflect() protoreflect.Message

func (*StreamingInfo) Reset

func (x *StreamingInfo) Reset()

func (*StreamingInfo) String

func (x *StreamingInfo) String() string

type StreamingServer

type StreamingServer interface {
	Search(context.Context, *SearchQuery) (*SearchRes, error)
	GetArtist(context.Context, *Id) (*Artist, error)
	GetArtistFull(context.Context, *Id) (*ArtistFull, error)
	GetAlbumFull(context.Context, *Id) (*AlbumFull, error)
	GetPlaylist(context.Context, *Id) (*Playlist, error)
	GetPlaylistFull(context.Context, *Id) (*PlaylistFull, error)
	GetTrack(context.Context, *Id) (*Track, error)
	GetPageEntry(context.Context, *Id) (*PageEntry, error)
	GetPage(context.Context, *emptypb.Empty) (*Page, error)
	GetStreamingInfo(context.Context, *Id) (*StreamingInfo, error)
	ListArtistPopularTracks(context.Context, *Id) (*Tracks, error)
	ListUserArtists(context.Context, *emptypb.Empty) (*Artists, error)
	ListUserAlbums(context.Context, *emptypb.Empty) (*Albums, error)
	ListUserPlaylists(context.Context, *emptypb.Empty) (*Playlists, error)
	// contains filtered or unexported methods
}

StreamingServer is the server API for Streaming service. All implementations must embed UnimplementedStreamingServer for forward compatibility.

type Track

type Track struct {
	Id       string               `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Title    string               `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	ImageUrl *string              `protobuf:"bytes,3,opt,name=image_url,json=imageUrl,proto3,oneof" json:"image_url,omitempty"`
	Duration *durationpb.Duration `protobuf:"bytes,4,opt,name=duration,proto3" json:"duration,omitempty"`
	Num      int32                `protobuf:"varint,5,opt,name=num,proto3" json:"num,omitempty"`
	Album    *Album               `protobuf:"bytes,6,opt,name=album,proto3" json:"album,omitempty"`
	Artists  []*Artist            `protobuf:"bytes,7,rep,name=artists,proto3" json:"artists,omitempty"`
	Disc     int32                `protobuf:"varint,8,opt,name=disc,proto3" json:"disc,omitempty"`
	Version  string               `protobuf:"bytes,9,opt,name=version,proto3" json:"version,omitempty"`
	RadioId  *string              `protobuf:"bytes,10,opt,name=radio_id,json=radioId,proto3,oneof" json:"radio_id,omitempty"`
	// contains filtered or unexported fields
}

func (*Track) Descriptor deprecated

func (*Track) Descriptor() ([]byte, []int)

Deprecated: Use Track.ProtoReflect.Descriptor instead.

func (*Track) GetAlbum

func (x *Track) GetAlbum() *Album

func (*Track) GetArtists

func (x *Track) GetArtists() []*Artist

func (*Track) GetDisc

func (x *Track) GetDisc() int32

func (*Track) GetDuration

func (x *Track) GetDuration() *durationpb.Duration

func (*Track) GetId

func (x *Track) GetId() string

func (*Track) GetImageUrl

func (x *Track) GetImageUrl() string

func (*Track) GetNum

func (x *Track) GetNum() int32

func (*Track) GetRadioId

func (x *Track) GetRadioId() string

func (*Track) GetTitle

func (x *Track) GetTitle() string

func (*Track) GetVersion

func (x *Track) GetVersion() string

func (*Track) ProtoMessage

func (*Track) ProtoMessage()

func (*Track) ProtoReflect

func (x *Track) ProtoReflect() protoreflect.Message

func (*Track) Reset

func (x *Track) Reset()

func (*Track) String

func (x *Track) String() string

type Tracks

type Tracks struct {
	List []*Track `protobuf:"bytes,2,rep,name=list,proto3" json:"list,omitempty"`
	// contains filtered or unexported fields
}

func (*Tracks) Descriptor deprecated

func (*Tracks) Descriptor() ([]byte, []int)

Deprecated: Use Tracks.ProtoReflect.Descriptor instead.

func (*Tracks) GetList

func (x *Tracks) GetList() []*Track

func (*Tracks) ProtoMessage

func (*Tracks) ProtoMessage()

func (*Tracks) ProtoReflect

func (x *Tracks) ProtoReflect() protoreflect.Message

func (*Tracks) Reset

func (x *Tracks) Reset()

func (*Tracks) String

func (x *Tracks) String() string

type UnimplementedStreamingServer

type UnimplementedStreamingServer struct{}

UnimplementedStreamingServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStreamingServer) GetAlbumFull

func (UnimplementedStreamingServer) GetArtist

func (UnimplementedStreamingServer) GetArtistFull

func (UnimplementedStreamingServer) GetPage

func (UnimplementedStreamingServer) GetPageEntry

func (UnimplementedStreamingServer) GetPlaylist

func (UnimplementedStreamingServer) GetPlaylistFull

func (UnimplementedStreamingServer) GetStreamingInfo

func (UnimplementedStreamingServer) GetTrack

func (UnimplementedStreamingServer) ListArtistPopularTracks

func (UnimplementedStreamingServer) ListArtistPopularTracks(context.Context, *Id) (*Tracks, error)

func (UnimplementedStreamingServer) ListUserAlbums

func (UnimplementedStreamingServer) ListUserArtists

func (UnimplementedStreamingServer) ListUserPlaylists

func (UnimplementedStreamingServer) Search

type UnsafeStreamingServer

type UnsafeStreamingServer interface {
	// contains filtered or unexported methods
}

UnsafeStreamingServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StreamingServer will result in compilation errors.

Jump to